<?php
namespace Teknisa\PED\Modules\Pedidos\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Doctrine\ORM\Query\ResultSetMapping;

class ped00100PedidosFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }
    
    
    public function insertVendedorPedAux($params) {
        
        try {

            $sql = "INSERT INTO VENDPEDAUX (CDFILIAL, NRPEDIDO, CDVENDEDOR) VALUES (:P_CDFILIAL, :P_NRPEDIDO, :P_CDVENDEDOR)";
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }   catch (\Exception $e) {
                
                throw $e;
                
        }
        
    }
    
     public function deleteVendedorPedAux($params) {
        
        try {

            $sql = "DELETE FROM VENDPEDAUX WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDO = :P_NRPEDIDO AND CDVENDEDOR = :P_CDVENDEDOR";
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }   catch (\Exception $e) {
                
                throw $e;
                
        }
        
    }
    
    public function deleteAllVendPedAux($params) {

        try {
            $this->connection->beginTransaction();
            $sql = "DELETE FROM VENDPEDAUX WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDO = :P_NRPEDIDO";
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            $this->connection->commit();
            return ['done'];
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function selectVendPedAux($params) {
            
        try {
            $sql = "SELECT CDVENDEDOR FROM VENDPEDAUX WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDO = :P_NRPEDIDO";
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            $result = $std->fetchAll();
            return $result;
        }   catch (\Exception $e) {
            throw $e;
        }
    }

    public function getComissaoVend($pedido, $item, $request, $response) {
       
       try {
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_COMISSAOVEND');           //('GERA_COMISSAOVEND')
            $procedure->addParam(new Param('P_CDFILIAL'    , Param::PARAM_INPUT, $pedido['CDFILIAL']               , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDO'    , Param::PARAM_INPUT, $pedido['NRPEDIDO']               , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDVENDEDOR'  , Param::PARAM_INPUT, $pedido['CDVENDEDOR']             , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDOPERADOR'  , Param::PARAM_INPUT, $pedido['CDOPELANPED']            , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRITEMPED'   , Param::PARAM_INPUT, $item['NRITEMPED']                , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDSITITEMPED', Param::PARAM_INPUT, $item['IDSITITEMPED']             , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRODUTO'   , Param::PARAM_INPUT, $item['CDPRODUTO']                , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_VRPREUNITPED', Param::PARAM_INPUT, $item['VRPREUNITPED']             , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_OLDCDVENDE'  , Param::PARAM_INPUT, null                              , Param::PARAM_TYPE_STR));
            
            $procedure->execute(); //Invoca a procedure para gerar comissão
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
            throw $e;
        }
    }

    public function getImpostoItem($pedido, $item, $request, $response, $idmobile) {
        try {
            // $this->entityManager->getConnection()->beginTransaction();
            
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'IMPOSTO_ITEMPEDIDO');
            $procedure->addParam(new Param('P_EMPRESA'   , Param::PARAM_INPUT,  $pedido['CDEMPRESA']                         , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_INSCESTA'  , Param::PARAM_INPUT,  $pedido['CDINSCESTA']                        , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CLIENTE'   , Param::PARAM_INPUT,  $pedido['CDCLIENTE']                         , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_FILIDEST'  , Param::PARAM_INPUT,  $pedido['CDFILIALPED']                       , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_FILIAL'    , Param::PARAM_INPUT,  $item['CDFILIAL']                            , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDO'  , Param::PARAM_INPUT,  $item['NRPEDIDO']                            , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRITEMPED' , Param::PARAM_INPUT,  $item['NRITEMPED']                           , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_INIVALID'  , Param::PARAM_INPUT,  $item['DTENTITPED']                          , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDTIPOOPER', Param::PARAM_INPUT,  $pedido['CDTIPOOPER']                        , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDTIPOOPER', Param::PARAM_INPUT,  $pedido['IDORIGDESTOP']                      , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDMOBILE'  , Param::PARAM_INPUT,  $idmobile                                    , Param::PARAM_TYPE_STR));
            $procedure->execute(); //Invoca a procedure para gerar imposto para os itens
            // $this->entityManager->getConnection()->commit();
            
        } catch (\Exception $e) {
            // $this->entityManager->rollback();
            throw $e;
        }
    }

    public function getTotalImposto($filial, $nrpedido, $request, $response) {
        try {

            $this->entityManager->getConnection()->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'IMPOSTO_PEDIDO');
            $procedure->addParam(new Param('P_FILIAL'   , Param::PARAM_INPUT,  $filial     , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDO' , Param::PARAM_INPUT,  $nrpedido   , Param::PARAM_TYPE_STR));
            $procedure->execute(); //Invoca a procedure para gerar imposto para os itens
            
            $this->entityManager->getConnection()->commit();
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function geraReserva($item, $response) {
        
        try {
            $this->entityManager->getConnection()->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'INSERE_RESERPRODPED');
            
            $procedure->addParam(new Param('P_CDFILIAL' , Param::PARAM_INPUT, $item['CDFILIAL']     , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDO' , Param::PARAM_INPUT, $item['NRPEDIDO']     , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRITEMPED', Param::PARAM_INPUT, $item['NRITEMPED']    , Param::PARAM_TYPE_STR));
            // $procedure->addParam(new Param('P_TODOS'    , Param::PARAM_INPUT, $nrpedido          , Param::PARAM_TYPE_STR));
            
            $procedure->execute(); 
            $this->entityManager->getConnection()->commit();
            // var_dump($response);
            
        } catch (\Exception $e) {
            $response->setError(new Error("Error. ". $e->getMessage(), 500));
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function returnImposto($CDFILIAL, $NRPEDIDO, $NRORG) {
        try {

            $sql = "SELECT VRIMPOSTOITPED FROM IMPITEMPEDIDO
                    WHERE CDFILIAL = :CDFILIAL
                    AND NRPEDIDO = :NRPEDIDO
                    AND NRORG = :NRORG";

            $params = array('CDFILIAL' => $CDFILIAL,
                            'NRPEDIDO' => $NRPEDIDO,
                            'NRORG' => $NRORG);
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
        }catch (\Exception $e) {
            throw $e;
        }
    }

        const GET_VALORES_PEDIDO  ="SELECT 
                                        I.NRORG,
                                        I.CDFILIAL,
                                        I.NRPEDIDO,
                                        (I.VRITEM + NVL(E.VRENCARGO,0) + NVL(IM.VRIMPOSTO,0)) VRTOTALPED,
                                        I.VRITEM AS VRTOTPEDLIQ,
                                        ((I.VRITEM + NVL(E.VRENCARGO,0) + NVL(IM.VRIMPOSTO,0)) - I.VRITEM) VALORIMPOSTO
                                    FROM PEDIDO P,
                                        (SELECT I.NRORG,
                                            I.CDFILIAL,
                                            I.NRPEDIDO,
                                            SUM((I.QTITEMPED * I.VRPREUNITPED) - (I.VRDESITPED)) VRITEM
                                        FROM ITEMPEDIDO I
                                        GROUP BY I.NRORG,
                                            I.NRPEDIDO,
                                            I.CDFILIAL
                                        ) I,
                                        (SELECT E.NRORG,
                                            E.CDFILIAL,
                                            E.NRPEDIDO,
                                            SUM(
                                                CASE EN.IDENCARGO
                                                WHEN 'A'
                                                    THEN TO_CHAR(NVL(E.VRENCARGOPED,0))
                                                WHEN 'D'
                                                    THEN TO_CHAR(NVL(E.VRENCARGOPED,0) * -1)
                                                ELSE '0'
                                                END
                                            ) VRENCARGO
                                        FROM ENCARGOPED E,
                                            ENCARGO EN
                                        WHERE E.CDENCARGO = EN.CDENCARGO
                                            AND E.NRORG       = EN.NRORG
                                        GROUP BY E.NRORG,
                                            E.CDFILIAL,
                                            E.NRPEDIDO
                                        ) E,
                                        (SELECT IP.NRORG,
                                            IP.CDFILIAL,
                                            IP.NRPEDIDO,
                                            SUM(
                                                CASE IM.IDTRATIMPO
                                                WHEN 'A'
                                                    THEN TO_CHAR(NVL(IP.VRIMPOSTOITPED,0))
                                                WHEN 'D'
                                                    THEN TO_CHAR(NVL(IP.VRIMPOSTOITPED,0) * -1)
                                                    ELSE '0'
                                                    END
                                            ) VRIMPOSTO
                                        FROM IMPOSTO IM,
                                            IMPITEMPEDIDO IP
                                        WHERE IP.CDIMPOSTO = IM.CDIMPOSTO
                                            AND IP.NRORG       = IM.NRORG
                                        GROUP BY IP.NRORG,
                                            IP.CDFILIAL,
                                            IP.NRPEDIDO
                                        ) IM
                                    WHERE P.CDFILIAL        = I.CDFILIAL (+)
                                        AND P.NRPEDIDO              = I.NRPEDIDO (+)
                                        AND P.NRORG                 = I.NRORG (+)
                                        AND P.CDFILIAL              = E.CDFILIAL (+)
                                        AND P.NRPEDIDO              = E.NRPEDIDO (+)
                                        AND P.NRORG                 = E.NRORG (+)
                                        AND P.CDFILIAL              = IM.CDFILIAL (+)
                                        AND P.NRPEDIDO              = IM.NRPEDIDO (+)
                                        AND P.NRORG                 = IM.NRORG (+)
                                        AND P.CDFILIAL              = :P_CDFILIAL
                                        AND P.NRPEDIDO              = :P_NRPEDIDO";

    public function getValoresPedido($cdfilial, $nrpedido){
        try {
            $params = array(
                'P_CDFILIAL' => $cdfilial,
                'P_NRPEDIDO' => $nrpedido
            );
            return $this->entityManager->getConnection()->fetchAll(self::GET_VALORES_PEDIDO, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

        const GET_MAX_NRDADOADICPED = "SELECT NVL(MAX(NRDADOADICPED), '001') AS MAX
                                    FROM DADOSADICPED
                                    WHERE CDFILIAL = :P_CDFILIAL
                                        AND NRPEDIDO = :P_NRPEDIDO";

    public function getMaxNrdadoadicped($cdfilial, $nrpedido){
        try {
            $params = array(
                'P_CDFILIAL' => $cdfilial,
                'P_NRPEDIDO' => $nrpedido
            );
            return $this->entityManager->getConnection()->fetchAll(self::GET_MAX_NRDADOADICPED, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
        const INSERT_HISITEMPED = "INSERT INTO HISITEMPED
                                (IDSITANTHIST, IDSITATUHIST, DTHRHIST, CDFILIAL, NRPEDIDO, NRITEMPED, NRORG)
                              VALUES (:P_IDSITANTHIST,
                                    :P_IDSITATUHIST,
                                    :P_DTHRHIST,
                                    :P_CDFILIAL,
                                    :P_NRPEDIDO,
                                    :P_NRITEMPED,
                                    :P_NRORG)";
    
    public function insertHist($historico) {
        try {
            $params = array(
                'P_IDSITANTHIST'=>  $historico['IDSITANTHIST'],
                'P_IDSITATUHIST'=>  $historico['IDSITATUHIST'],
                'P_DTHRHIST'=> $historico['DTHRHIST'],
                'P_CDFILIAL'=> $historico['CDFILIAL'],
                'P_NRPEDIDO'=> $historico['NRPEDIDO'],
                'P_NRITEMPED'=> $historico['NRITEMPED'],
                'P_NRORG'=> $historico['NRORG']
            );
            return $this->entityManager->getConnection()->executeQuery(self::INSERT_HISITEMPED, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
            const INSERT_ITEMPEDIDOTRAB = "INSERT INTO ITEMPEDIDOTRAB
                                (CDFILIAL,NRPEDIDO, NRITEMPED, DTENTITPED, CDPRODUTO, QTITEMPED, VRPREUNITPED, VRDESITPED)
                              VALUES (:P_CDFILIAL,
                                      :P_NRPEDIDO,
                                      :P_NRITEMPED,
                                      :P_DTENTITPED,
                                      :P_CDPRODUTO,
                                      :P_QTITEMPED,
                                      :P_VRPREUNITPED,
                                      :P_VRDESITPED)";
    
    public function insereItemtrab($item, $response) {
        try {
            $params = array(
                'P_CDFILIAL' => $item['CDFILIAL'],
                'P_NRPEDIDO' => $item['NRPEDIDO'],
                'P_NRITEMPED' => $item['NRITEMPED'],
                'P_DTENTITPED' => $item['DTENTITPED'],
                'P_CDPRODUTO' => $item['CDPRODUTO'],
                'P_QTITEMPED' => $item['QTITEMPED'],
                'P_VRPREUNITPED' => $item['VRPREUNITPED'],
                'P_VRDESITPED' => $item['VRDESITPED'],
                'P_NRORG'=> $item['NRORG']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPEDIDOTRAB, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    
    public function consultaPendencia($params) {
        
        $CONSULTA_PENDENCIA = "SELECT
                                   NF.CDCLIENTE,
                                   NF.CDFILIAL,
                                   NF.NRLANCTONF,
                                   NF.NRNOTAFISC,
                                   CO.DTATUAVENREC,
                                   CO.VRATUAREC
                                FROM
                                    CONTARECEBER   CO,
                                    NOTAFISCAL     NF,
                                    BOLETRECEBER   BO,
                                    CLIENTE        C,
                                    PARAMPEDIDO    P
                                WHERE
                                    ( NF.CDCLIENTE = :P_CDCLIENTE )
                                    AND ( CO.CDFILIAL = NF.CDFILIAL )
                                    AND ( CO.NRLANCTONF = NF.NRLANCTONF )
                                    AND ( CO.NRLANBOLREC = BO.NRLANBOLREC )
                                    AND ( CO.CDFILIAL = BO.CDFILIAL )
                                    AND ( P.CDFILIAL = :P_CDFILIAL )
                                    AND ( C.CDCLIENTE = :P_CDCLIENTE )
                                    AND ( BO.DTVENBOLREC < ( SYSDATE - NVL(C.NRDIAPFINAPR, P.NRDIAPENDFIN) ) )
                                    AND ( CO.IDSTATREC IN (
                                        'A',
                                        'D'
                                    ) )
                                    AND ( NF.IDSTATUS IN (
                                        'A',
                                        'E'
                                    ) )";
        $stmt = $this->connection->prepare($CONSULTA_PENDENCIA);
        $stmt->execute($params);
        $result = $stmt->fetchAll();
        return $result;
    }
    
    public function consultaIdPendFin($params) {
        
        $CONSULTA_IDPEND_PARAMPEDIDO = "SELECT
                                        NVL(C.IDPFINAPRPED, P.IDPENDFINAN) AS IDPENDFINAN
                                    FROM
                                        PARAMPEDIDO   P,
                                        CLIENTE       C
                                    WHERE
                                        ( P.CDFILIAL = :P_CDFILIAL )
                                        AND ( C.CDCLIENTE = :P_CDCLIENTE )";
                                
        $stmt = $this->connection->prepare($CONSULTA_IDPEND_PARAMPEDIDO);
        $stmt->execute($params);
        $result = $stmt->fetch();
        return $result;
    }
    
    public function consultaIdPendFinGroup($params) {
        
        $CONSULTA_PARAMPEDIDO = "SELECT
                                        NVL(C.IDPFINAPRPED, P.IDPENDFINAN) AS IDPENDFINAN
                                    FROM
                                        PARAMPEDIDO   P,
                                        CLIENTE       C
                                    WHERE
                                        ( P.CDFILIAL IN (:P_CDFILIAL) )
                                        AND ( C.CDCLIENTE IN (:P_CDCLIENTE) )";
        $rsm = new ResultSetMapping;        
        $query = $this->entityManager->createNativeQuery($CONSULTA_PARAMPEDIDO,$rsm);
        $query->setParameter('P_CDFILIAL',$params['P_CDFILIAL']);
        $query->setParameter('P_CDCLIENTE',$params['P_CDCLIENTE']);
        $result = $query->getResult();
        // var_dump($result);
        return $result;
    }
    const DELETE_ITEMPEDIDOTRAB = "DELETE FROM ITEMPEDIDOTRAB
                                        WHERE 
                                            CDFILIAL = :P_CDFILIAL AND
                                            NRPEDIDO = :P_NRPEDIDO";
    
    public function deleteItemtrab($item, $response) {
        try {
            $params = array(
                'P_CDFILIAL' => $item['CDFILIAL'],
                'P_NRPEDIDO' => $item['NRPEDIDO']
            );
            return $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEMPEDIDOTRAB, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    const DELETE_IMPITEMPEDIDOTRAB = "DELETE FROM IMPITEMPEDIDOTRAB
                                        WHERE 
                                            CDFILIAL = :P_CDFILIAL AND
                                            NRPEDIDO = :P_NRPEDIDO";

    public function deleteImpitempedidotrab($pedido, $response) {
        try {
            $params = array(
                'P_CDFILIAL' => $pedido['CDFILIAL'],
                'P_NRPEDIDO' => $pedido['NRPEDIDO']
            );
            return $this->entityManager->getConnection()->executeQuery(self::DELETE_IMPITEMPEDIDOTRAB, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getImpitempedidotrab($pedido) {
        try {
            $sql = "SELECT IP.CDFILIAL,
                        IP.NRPEDIDO,
                        IP.NRITEMPED,
                        SUM(
                        CASE IM.IDTRATIMPO
                          WHEN 'A'
                          THEN TO_CHAR(NVL(IP.VRIMPOSTOITPED,0))
                          WHEN 'D'
                          THEN TO_CHAR(NVL(IP.VRIMPOSTOITPED,0) * -1)
                          ELSE '0'
                        END ) VRIMPOSTOITPED
                      FROM IMPOSTO IM,
                        IMPITEMPEDIDOTRAB IP
                      WHERE IP.CDIMPOSTO = IM.CDIMPOSTO
                      AND IP.CDFILIAL = :P_CDFILIAL
                      AND IP.NRPEDIDO = :P_NRPEDIDO 
                      GROUP BY IP.CDFILIAL,
                        IP.NRPEDIDO,
                        IP.NRITEMPED
                    ";
            $params = array('P_CDFILIAL' => $pedido['CDFILIAL'],
                            'P_NRPEDIDO' => $pedido['NRPEDIDO']);
                
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    const INSERT_ENCARGOTRAB = "INSERT INTO ENCARGOPEDTRAB
            (CDFILIAL, NRPEDIDO, CDENCARGO, VRENCARGOPED)
              VALUES (:P_CDFILIAL,
                  :P_NRPEDIDO,
                  :P_CDENCARGO,
                  :P_VRENCARGOPED)";
    public function saveEncargotrab($encargo) {
        try {
            $params = array(
                'P_CDFILIAL' => $encargo['CDFILIAL'],
                'P_NRPEDIDO' => $encargo['NRPEDIDO'],
                'P_CDENCARGO' => $encargo['CDENCARGO'],
                'P_VRENCARGOPED' => $encargo['VRENCARGOPED']
            );
            return $this->entityManager->getConnection()->executeQuery(self::INSERT_ENCARGOTRAB, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
        const DELETE_ENCARGOTRAB = "DELETE FROM ENCARGOPEDTRAB
                                        WHERE 
                                            CDFILIAL = :P_CDFILIAL AND
                                            NRPEDIDO = :P_NRPEDIDO";

    public function deleteEncargotrab($pedido) {
        try {
            $params = array(
                'P_CDFILIAL' => $pedido['CDFILIAL'],
                'P_NRPEDIDO' => $pedido['NRPEDIDO']
            );
            return $this->entityManager->getConnection()->executeQuery(self::DELETE_ENCARGOTRAB, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getImpostosped($pedido) {

        $sql = "SELECT CDFILIAL,
                       NRPEDIDO,
                       CDIMPOSTO,
                       SUM(VRIMPOSTOITPED) AS VRIMPOSTOTAL,
                       SUM(VRBASECALCITPED) AS VRBASETOTAL
                FROM IMPITEMPEDIDO
                WHERE CDFILIAL   = :P_CDFILIAL AND
                       NRPEDIDO  = :P_NRPEDIDO
                GROUP BY CDFILIAL, NRPEDIDO, CDIMPOSTO
        ";
        $params = array('P_CDFILIAL' => $pedido['CDFILIAL'],
                        'P_NRPEDIDO' => $pedido['NRPEDIDO']);
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function insereImpostototped($pedido) {
        $params = array('P_CDFILIAL' => $pedido['CDFILIAL'],
                        'P_NRPEDIDO' => $pedido['NRPEDIDO']);
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
        const INSERT_IMPOSNFTOTPED = "INSERT INTO IMPOSNFTOTPED
                        (CDFILIAL, NRPEDIDO, CDIMPOSTO,
                         VRTOTIMPPED, VRTOTBCALCPED)
                    VALUES
                        (:CDFILIAL, :NRPEDIDO, :CDIMPOSTO,
                         :VRTOTIMPPED, :VRTOTBCALCPED)
                    ";
    public function saveImpostototped($imp) {
        try {
            $params = array(
                'CDFILIAL' => $imp['CDFILIAL'],
                'NRPEDIDO' => $imp['NRPEDIDO'],
                'CDIMPOSTO' => $imp['CDIMPOSTO'],
                'VRTOTIMPPED' => $imp['VRIMPOSTOTAL'],
                'VRTOTBCALCPED' => $imp['VRBASETOTAL']
            );
            return $this->entityManager->getConnection()->executeQuery(self::INSERT_IMPOSNFTOTPED, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getModpgtoPed($params) {

        try {
            $sql = "SELECT CDMODPGTO FROM PEDIDO WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDO = :P_NRPEDIDO";
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getDataEntrega($filial, $dtbase) {
        try {
            $sql = "SELECT DATAUTIL(:P_CDFILIAL, :P_DTBASE, NRDIASENTPED) AS DTENTREGA FROM PARAMPEDIDO WHERE CDFILIAL = :P_CDFILIAL";
            
            $params = array(
                'P_CDFILIAL' => $filial,
                'P_DTBASE' => $dtbase
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    // public function getItensPedido($pedido) {
    //     try {
    //         $sql = "SELECT * FROM ITEMPEDIDO
    //                 WHERE CDFILIAL = :P_CDFILIAL
    //                 AND NRPEDIDO = :P_NRPEDIDO";
            
    //         $params = array(
    //             'P_CDFILIAL' => $pedido['CDFILIAL'],
    //             'P_NRPEDIDO' => $pedido['NRPEDIDO']
    //         );
            
    //         $std = $this->connection->prepare($sql);
    //         $std->execute($params);
    //         return $std->fetchAll();
    //     } catch (\Exception $e) {
    //         throw $e;
    //     }
    // }
    
    public function tabelaItemPedido($pedido) {
        try {
            $sql = "SELECT IP.QTITEMPED, IP.VRPREUNITPED, P.NMPRODUTO 
                    FROM ITEMPEDIDO IP, PRODUTO P
                    WHERE IP.CDPRODUTO = P.CDPRODUTO
                        AND CDFILIAL = :P_CDFILIAL
                        AND NRPEDIDO = :P_NRPEDIDO";
            
            $params = array(
                'P_CDFILIAL' => $pedido['CDFILIAL'],
                'P_NRPEDIDO' => $pedido['NRPEDIDO']
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    public function endEntregaPed($pedido) {
        try {
            $sql = "SELECT * FROM DADOSENDPED 
                            WHERE IDTPENDECLIE IN ('P','T')
                            AND CDCLIENTE = :P_CDCLIENTE
                            AND NRPEDIDO = :P_NRPEDIDO
                            AND CDFILIAL = :P_CDFILIAL";
            
            $params = array(
                'P_NRPEDIDO' => $pedido['NRPEDIDO'],
                'P_CDFILIAL' => $pedido['CDFILIAL'],
                'P_CDCLIENTE' => $pedido['CDCLIENTE'],

            ); 
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    public function getSmtp($pedido){
        try {
            $sql = "SELECT DSLOGINSMTP, CDSENHEMAILF, DSSMTPEMAILF 
                                FROM ENDEFILI E, PEDIDO P 
                                WHERE NRPEDIDO = :P_NRPEDIDO 
                                AND P.CDFILIAL = :P_CDFILIAL
                                AND P.CDFILIAL = E.CDFILIAL";
            
            $params = array(
                'P_NRPEDIDO' => $pedido['NRPEDIDO'],
                'P_CDFILIAL' => $pedido['CDFILIAL']
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }
}